==> haskell-tasty-smallcheck-0.8.2-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-8JCncAzfoniLcYJ4yaKksQ
key:                  tasty-smallcheck-0.8.2-8JCncAzfoniLcYJ4yaKksQ
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  aa998021b38f40ad43013119a00b72ba
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tasty-smallcheck-0.8.2
hs-libraries:         HStasty-smallcheck-0.8.2-8JCncAzfoniLcYJ4yaKksQ
depends:
    base-4.15.0.0 optparse-applicative-0.16.1.0-BHBH1F3tdBzGhkh4ZPKU37
    smallcheck-1.2.1-7t1ag7sze5l14frZH1gv3S
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.2-1qeMbsGSBcw7OKI3VOF0cH

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-1AUCuszahaV3CAI159ZRBE
key:                  tasty-smallcheck-0.8.2-1AUCuszahaV3CAI159ZRBE
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  f0da1cacb221db5e53315b35fdce93bd
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tasty-smallcheck-0.8.2
hs-libraries:         HStasty-smallcheck-0.8.2-1AUCuszahaV3CAI159ZRBE
depends:
    base-4.15.0.0 optparse-applicative-0.16.1.0-GAf19vjqBowD5QTDnxMOQQ
    smallcheck-1.2.1-7t1ag7sze5l14frZH1gv3S
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.2-DmpA164azzOJtaMxnfJrIk

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
